"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventCache = void 0;
var EventCache = /** @class */ (function () {
    /**
     * An EventCache stores and maintains a list of the most recent events.
     * @param maxSize The maximum number of events to keep in the cache.
     */
    function EventCache(maxSize) {
        if (maxSize === void 0) { maxSize = 10; }
        this.cache = [];
        this.maxSize = maxSize;
    }
    /**
     * Adds an event to the cache.
     * @param event The event to add to the cache.
     */
    EventCache.prototype.enqueue = function (event) {
        if (this.cache.length === this.maxSize) {
            this.dequeue();
        }
        this.cache.push(event);
    };
    /**
     * Remove and return the oldest event in the cache.
     * @returns The oldest event in the cache, or undefined if the cache is empty.
     */
    EventCache.prototype.dequeue = function () {
        return this.cache.shift();
    };
    /**
     * Returns the most recent event in the cache without removing it.
     * @returns The most recent event in the cache, or undefined if the cache is empty.
     */
    EventCache.prototype.mostRecent = function () {
        return this.cache[this.cache.length - 1];
    };
    /**
     * Returns all items in the cache that have been created since the given date. The most recent event will be at the last index.
     * @param date
     * @returns
     */
    EventCache.prototype.allEventsSince = function (date) {
        return this.cache.filter(function (event) { return event.detail.timestamp > date; });
    };
    Object.defineProperty(EventCache.prototype, "values", {
        /**
         * Returns all the events currently in the cache, with the last index being the most recent event.
         */
        get: function () {
            return this.cache;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(EventCache.prototype, "length", {
        /**
         * Returns the number of events currently in the cache.
         */
        get: function () {
            return this.cache.length;
        },
        enumerable: false,
        configurable: true
    });
    return EventCache;
}());
exports.EventCache = EventCache;
