import { EventCache } from "./EventCache";
import { EventDetail } from "./EventDetail";
import { EventDispatcherOptions } from "./EventDispatcherOptions";
export declare class EventDispatcher<TPayload> {
    eventKey: string;
    eventCache: EventCache;
    constructor(eventName: string, options?: EventDispatcherOptions);
    /**
     * Dispatch the event with the given payload. The event will be cached.
     * @param payload The payload to send with the event.
     */
    dispatch(payload: TPayload): void;
    /**
     *
     * @returns The most recent event in the cache, or undefined if the cache is empty.
     */
    getLastEvent(): CustomEvent<EventDetail<TPayload>> | undefined;
    /**
     * Returns cached events
     * @param date Optional date to filter events
     * @returns All events that have occurred since the given date, or all events if no date is given
     */
    getCachedEvents(date?: Date): CustomEvent<EventDetail<TPayload>>[];
    /**
     * Updates the event key to change the receiver of the events but preserve the cache.
     * @param newKey The new event name to use for this dispatcher
     */
    updateKey(newKey: string): void;
}
