"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventDispatcher = void 0;
var EventCache_1 = require("./EventCache");
var EventDispatcher = /** @class */ (function () {
    function EventDispatcher(eventName, options) {
        var _a;
        this.eventKey = eventName;
        this.eventCache = new EventCache_1.EventCache((_a = options === null || options === void 0 ? void 0 : options.maxCacheSize) !== null && _a !== void 0 ? _a : 25);
    }
    /**
     * Dispatch the event with the given payload. The event will be cached.
     * @param payload The payload to send with the event.
     */
    EventDispatcher.prototype.dispatch = function (payload) {
        var detail = {
            payload: payload,
            timestamp: new Date(),
            dispatcher: this,
            eventKey: this.eventKey,
        };
        var customEvent = new CustomEvent(this.eventKey, { detail: detail });
        this.eventCache.enqueue(customEvent);
        window.dispatchEvent(customEvent);
    };
    /**
     *
     * @returns The most recent event in the cache, or undefined if the cache is empty.
     */
    EventDispatcher.prototype.getLastEvent = function () {
        return this.eventCache.mostRecent();
    };
    /**
     * Returns cached events
     * @param date Optional date to filter events
     * @returns All events that have occurred since the given date, or all events if no date is given
     */
    EventDispatcher.prototype.getCachedEvents = function (date) {
        if (date) {
            return this.eventCache.allEventsSince(date);
        }
        return this.eventCache.values;
    };
    /**
     * Updates the event key to change the receiver of the events but preserve the cache.
     * @param newKey The new event name to use for this dispatcher
     */
    EventDispatcher.prototype.updateKey = function (newKey) {
        this.eventKey = newKey;
    };
    return EventDispatcher;
}());
exports.EventDispatcher = EventDispatcher;
