"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
/**
 * Subscribes (or listens) for events with the provided key.
 * @param eventKey The unique identifier for the type of event to lsten for. This should match the event key used by the component implementing the useEventDispatch hook.
 * @param callback A callback that will be invoked with the EventDetail anytime the event is dispatched.
 * @returns The EventDetail of the most recently dispatched event.
 */
var useEventListen = function (eventKey, callback) {
    var _a = (0, react_1.useState)(null), previousDetail = _a[0], setPreviousDetail = _a[1];
    (0, react_1.useEffect)(function () {
        var eventCallback = function (event) {
            var detail = event.detail;
            callback && callback(detail);
            setPreviousDetail(detail);
        };
        window.addEventListener(eventKey, eventCallback);
        return function () {
            window.removeEventListener(eventKey, eventCallback);
        };
    }, [eventKey]);
    return previousDetail;
};
exports.default = useEventListen;
