export declare class EventCache {
    private cache;
    private maxSize;
    /**
     * An EventCache stores and maintains a list of the most recent events.
     * @param maxSize The maximum number of events to keep in the cache.
     */
    constructor(maxSize?: number);
    /**
     * Adds an event to the cache.
     * @param event The event to add to the cache.
     */
    enqueue(event: CustomEvent): void;
    /**
     * Remove and return the oldest event in the cache.
     * @returns The oldest event in the cache, or undefined if the cache is empty.
     */
    dequeue(): CustomEvent | undefined;
    /**
     * Returns the most recent event in the cache without removing it.
     * @returns The most recent event in the cache, or undefined if the cache is empty.
     */
    mostRecent(): CustomEvent | undefined;
    /**
     * Returns all items in the cache that have been created since the given date. The most recent event will be at the last index.
     * @param date
     * @returns
     */
    allEventsSince(date: Date): CustomEvent[];
    /**
     * Returns all the events currently in the cache, with the last index being the most recent event.
     */
    get values(): CustomEvent[];
    /**
     * Returns the number of events currently in the cache.
     */
    get length(): number;
}
