import { useEffect, useState } from "react";
import { EventDispatcher } from "../shared/EventDispatcher";
/**
 * Creates a custom event dispatcher function with the provided key that can be used to dispatch events to other components anywhere in the DOM.
 * @param eventKey The unique identifier for this event. Listening components can use this same key to listen for events.
 * @param options Options for the dispatcher.
 * @returns A function that can be used to dispatch events to other components.
 */
var useEventDispatch = function (eventKey, options) {
    var _a = useState(null), dispatcher = _a[0], setDispatcher = _a[1];
    useEffect(function () {
        if (!dispatcher) {
            setDispatcher(new EventDispatcher(eventKey, options));
        }
        if (eventKey !== (dispatcher === null || dispatcher === void 0 ? void 0 : dispatcher.eventKey)) {
            dispatcher === null || dispatcher === void 0 ? void 0 : dispatcher.updateKey(eventKey);
        }
    }, [eventKey, options]);
    /**
     * A dispatch function created by useEventDispatch.
     * @param payload The payload to send with the event.
     */
    var dispatch = function (payload) {
        if (payload === void 0) { payload = {}; }
        dispatcher === null || dispatcher === void 0 ? void 0 : dispatcher.dispatch(payload);
    };
    return dispatch;
};
export default useEventDispatch;
