import useEventDispatch from "../useEventDispatch";
import { useState } from "react";
import useEventListen from "../useEventListen";
/**
 * The useSharedState hook allows components referencing the same state key to share state from anywhere in the dom using synthetic events. This functions just like React useState, except updating the state here will update for any other components that reference the same state key.
 * @param initialState The initial state.
 * @param stateKey A string that uniquely identifies this state so that it can be shared across components. If omitted, this hook will function exactly the same as React useState.
 * @returns A tuple including the stateful value and a function to update it.
 */
var useSharedState = function (initialState, stateKey) {
    var _a = useState(initialState), state = _a[0], setState = _a[1];
    if (!stateKey) {
        return [state, setState];
    }
    var sendState = useEventDispatch(stateKey);
    useEventListen(stateKey, function (detail) {
        var _a;
        setState((_a = detail === null || detail === void 0 ? void 0 : detail.payload) !== null && _a !== void 0 ? _a : state);
    });
    var updateSharedState = function (value) {
        sendState(value);
    };
    return [state, updateSharedState];
};
export default useSharedState;
